# coding: utf-8

"""
    Kestra EE

    All API operations, except for Superadmin-only endpoints, require a tenant identifier in the HTTP path.<br/> Endpoints designated as Superadmin-only are not tenant-scoped.

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SchemaAttributeMutability(str, Enum):
    """
    SchemaAttributeMutability
    """

    """
    allowed enum values
    """
    IMMUTABLE = 'IMMUTABLE'
    READ_ONLY = 'READ_ONLY'
    READ_WRITE = 'READ_WRITE'
    WRITE_ONLY = 'WRITE_ONLY'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SchemaAttributeMutability from a JSON string"""
        return cls(json.loads(json_str))


